@@ -1,9 +1,13 @@
+import collections
+
 import flask as f
 
 from ..api import rule
 from ..api._endpoint import ApiEndpoint, maybe_login_required
 from ..entities._comparator import BenchmarkComparator, BenchmarkListComparator
 from ..entities._entity import NotFound
+from ..entities.commit import Commit
+from ..entities.compare import CompareSummarySerializer
 from ..entities.distribution import set_z_scores
 from ..entities.summary import Summary
 from ..hacks import set_display_batch, set_display_name
@@ -14,6 +18,8 @@ def _compare_entity(summary):
         "id": summary.id,
         "batch_id": summary.batch_id,
         "run_id": summary.run_id,
+        "case_id": summary.case_id,
+        "context_id": summary.context_id,
         "value": summary.mean,
         "unit": summary.unit,
         "benchmark": summary.display_name,
@@ -24,15 +30,73 @@ def _compare_entity(summary):
     }
 
 
-class CompareBenchmarksAPI(ApiEndpoint):
-    def _get(self, benchmark_id):
-        try:
-            summary = Summary.one(id=benchmark_id)
-        except NotFound:
-            self.abort_404_not_found()
-        set_z_scores([summary])
-        return summary
+def _get_pairs(baseline_items, contender_items):
+    """
+    You should be able to compare any run with any other run, so we can't
+    just key by case_id/context_id/machine_hash, or you couldn't compare runs
+    done on different machine, nor could you compare runs done in different
+    contexts.
 
+    Assumptions:
+        - A run contains exactly one machine.
+        - You are only ever comparing 2 runs or batches.
+    """
+    pairs = {}
+    baseline_items = _dedup_items(baseline_items)
+    contender_items = _dedup_items(contender_items)
+    baseline_counter = collections.Counter([i["case_id"] for i in baseline_items])
+    contender_counter = collections.Counter([i["case_id"] for i in contender_items])
+    for item in baseline_items:
+        case_id = item["case_id"]
+        simple = _simple_key(baseline_counter, contender_counter, case_id)
+        _add_pair(pairs, item, "baseline", simple)
+    for item in contender_items:
+        case_id = item["case_id"]
+        simple = _simple_key(baseline_counter, contender_counter, case_id)
+        _add_pair(pairs, item, "contender", simple)
+    return pairs
+
+
+def _simple_key(baseline_counter, contender_counter, case_id):
+    return baseline_counter[case_id] == 1 and contender_counter[case_id] == 1
+
+
+def _dedup_items(items):
+    filtered = {}
+    for item in items:
+        filtered[f'{item["case_id"]}-{item["context_id"]}'] = item
+    return filtered.values()
+
+
+def _add_pair(pairs, item, kind, simple):
+    case_id, context_id = item["case_id"], item["context_id"]
+    key = case_id if simple else f"{case_id}-{context_id}"
+    if key not in pairs:
+        pairs[key] = {"baseline": None, "contender": None}
+    pairs[key][kind] = item
+
+
+class CompareMixin:
+    def get_args(self, compare_ids):
+        raw = f.request.args.get("raw", "false").lower() in ["true", "1"]
+
+        threshold = f.request.args.get("threshold")
+        if threshold is not None:
+            threshold = int(threshold)
+
+        threshold_z = f.request.args.get("threshold_z")
+        if threshold_z is not None:
+            threshold_z = int(threshold_z)
+
+        try:
+            baseline_id, contender_id = compare_ids.split("...", 1)
+        except ValueError:
+            self.abort_404_not_found()
+
+        return raw, threshold, threshold_z, baseline_id, contender_id
+
+
+class CompareEntityEndpoint(ApiEndpoint, CompareMixin):
     @maybe_login_required
     def get(self, compare_ids):
         """
@@ -63,20 +127,8 @@ class CompareBenchmarksAPI(ApiEndpoint):
         tags:
           - Comparisons
         """
-        raw = f.request.args.get("raw", "false").lower() in ["true", "1"]
-
-        threshold = f.request.args.get("threshold")
-        if threshold is not None:
-            threshold = int(threshold)
-
-        threshold_z = f.request.args.get("threshold_z")
-        if threshold_z is not None:
-            threshold_z = int(threshold_z)
-
-        try:
-            baseline_id, contender_id = compare_ids.split("...", 1)
-        except ValueError:
-            self.abort_404_not_found()
+        args = self.get_args(compare_ids)
+        raw, threshold, threshold_z, baseline_id, contender_id = args
 
         baseline_summary = self._get(baseline_id)
         contender_summary = self._get(contender_id)
@@ -87,31 +139,17 @@ class CompareBenchmarksAPI(ApiEndpoint):
 
         baseline = _compare_entity(baseline_summary)
         contender = _compare_entity(contender_summary)
+        comparator = BenchmarkComparator(
+            baseline,
+            contender,
+            threshold,
+            threshold_z,
+        )
 
-        if raw:
-            return BenchmarkComparator(
-                baseline,
-                contender,
-                threshold,
-                threshold_z,
-            ).compare()
-        else:
-            return BenchmarkComparator(
-                baseline,
-                contender,
-                threshold,
-                threshold_z,
-            ).formatted()
+        return comparator.compare() if raw else comparator.formatted()
 
 
-class CompareBatchesAPI(ApiEndpoint):
-    def _get(self, batch_id):
-        summaries = Summary.all(batch_id=batch_id)
-        if not summaries:
-            self.abort_404_not_found()
-        set_z_scores(summaries)
-        return summaries
-
+class CompareListEndpoint(ApiEndpoint, CompareMixin):
     @maybe_login_required
     def get(self, compare_ids):
         """
@@ -142,70 +180,53 @@ class CompareBatchesAPI(ApiEndpoint):
         tags:
           - Comparisons
         """
-        raw = f.request.args.get("raw", "false").lower() in ["true", "1"]
-
-        threshold = f.request.args.get("threshold")
-        if threshold is not None:
-            threshold = int(threshold)
-
-        threshold_z = f.request.args.get("threshold_z")
-        if threshold_z is not None:
-            threshold_z = int(threshold_z)
-
-        try:
-            baseline_id, contender_id = compare_ids.split("...", 1)
-        except ValueError:
-            self.abort_404_not_found()
+        args = self.get_args(compare_ids)
+        raw, threshold, threshold_z, baseline_id, contender_id = args
 
         baselines = self._get(baseline_id)
         contenders = self._get(contender_id)
 
-        pairs = {}
+        baseline_items, contender_items = [], []
         for summary in baselines:
             set_display_name(summary)
             set_display_batch(summary)
-            self._add_pair(pairs, summary, "baseline")
+            baseline_items.append(_compare_entity(summary))
         for summary in contenders:
             set_display_name(summary)
             set_display_batch(summary)
-            self._add_pair(pairs, summary, "contender")
+            contender_items.append(_compare_entity(summary))
 
-        if raw:
-            result = BenchmarkListComparator(
-                pairs,
-                threshold,
-                threshold_z,
-            ).compare()
-        else:
-            result = BenchmarkListComparator(
-                pairs,
-                threshold,
-                threshold_z,
-            ).formatted()
+        pairs = _get_pairs(baseline_items, contender_items)
+        comparator = BenchmarkListComparator(
+            pairs,
+            threshold,
+            threshold_z,
+        )
 
+        result = comparator.compare() if raw else comparator.formatted()
         return f.jsonify(list(result))
 
-    def _has_unique_names(self, baselines, contenders):
-        baseline_names = set([x.case.name for x in baselines])
-        if len(baseline_names) != len(baselines):
-            return False
 
-        contender_names = set([x.case.name for x in contenders])
-        if len(contender_names) != len(contenders):
-            return False
-
-        return True
-
-    def _add_pair(self, pairs, summary, kind):
-        case = summary.case
-
-        if case.id not in pairs:
-            pairs[case.id] = {"baseline": None, "contender": None}
-
-        pairs[case.id][kind] = _compare_entity(summary)
+class CompareBenchmarksAPI(CompareEntityEndpoint):
+    def _get(self, benchmark_id):
+        try:
+            summary = Summary.one(id=benchmark_id)
+        except NotFound:
+            self.abort_404_not_found()
+        set_z_scores([summary])
+        return summary
 
 
-class CompareRunsAPI(CompareBatchesAPI):
+class CompareBatchesAPI(CompareListEndpoint):
+    def _get(self, batch_id):
+        summaries = Summary.all(batch_id=batch_id)
+        if not summaries:
+            self.abort_404_not_found()
+        set_z_scores(summaries)
+        return summaries
+
+
+class CompareRunsAPI(CompareListEndpoint):
     def _get(self, run_id):
         summaries = Summary.all(run_id=run_id)
         if not summaries:
@@ -214,9 +235,47 @@ class CompareRunsAPI(CompareBatchesAPI):
         return summaries
 
 
+class CompareCommitsAPI(CompareListEndpoint):
+    serializer = CompareSummarySerializer()
+
+    @maybe_login_required
+    def get(self, compare_shas):
+        """
+        ---
+        description: Compare benchmark results.
+        responses:
+            "200": "CompareSummary"
+            "401": "401"
+            "404": "404"
+        parameters:
+          - name: compare_shas
+            in: path
+            schema:
+                type: string
+            example: <baseline_sha>...<contender_sha>
+        tags:
+          - Comparisons
+        """
+        try:
+            baseline_sha, contender_sha = compare_shas.split("...", 1)
+        except ValueError:
+            self.abort_404_not_found()
+        baseline_commit = self._get(baseline_sha)
+        contender_commit = self._get(contender_sha)
+        return self.serializer.one.dump([baseline_commit, contender_commit])
+
+    def _get(self, sha):
+        try:
+            commit = Commit.one(sha=sha)
+        except NotFound:
+            self.abort_404_not_found()
+        return commit
+
+
 compare_benchmarks_view = CompareBenchmarksAPI.as_view("compare-benchmarks")
 compare_batches_view = CompareBatchesAPI.as_view("compare-batches")
 compare_runs_view = CompareRunsAPI.as_view("compare-runs")
+compare_commits_view = CompareCommitsAPI.as_view("compare-commits")
 
 rule(
     "/compare/benchmarks/<compare_ids>/",
@@ -233,3 +292,8 @@ rule(
     view_func=compare_runs_view,
     methods=["GET"],
 )
+rule(
+    "/compare/commits/<compare_shas>/",
+    view_func=compare_commits_view,
+    methods=["GET"],
+)
