@@ -9,6 +9,24 @@ from ..units import formatter_for_unit
 
 
 class TimeSeriesPlotMixin:
+    def get_outliers(self, benchmarks):
+        benchmarks_by_id = {b["id"]: b for b in benchmarks}
+
+        # top 3 outliers
+        outliers = sorted(
+            [
+                (abs(float(b["stats"]["z_score"])), b["id"])
+                for b in benchmarks
+                if b["stats"]["z_regression"] or b["stats"]["z_improvement"]
+            ],
+            reverse=True,
+        )[:3]
+
+        outliers = [benchmarks_by_id[o[1]] for o in outliers]
+        outlier_ids = [b["id"] for b in outliers]
+        outlier_names = [f'{b["display_batch"]}, {b["display_name"]}' for b in outliers]
+        return outliers, outlier_ids, outlier_names
+
     def get_history_plot(self, benchmark, run, i=0):
         history = self._get_history(benchmark)
         if history:
@@ -209,9 +227,10 @@ def time_series_plot(history, benchmark, run, height=250, width=1000):
         x_axis_type="datetime",
         plot_height=height,
         plot_width=width,
-        toolbar_location=None,
-        tools=[hover],
+        tools=[hover, "pan", "zoom_in", "zoom_out", "reset"],
+        x_range=(source.data["x"][0], source.data["x"][-1]),
     )
+    p.toolbar.logo = None
 
     p.xaxis.formatter = get_date_format()
     p.xaxis.major_label_orientation = 1
@@ -229,6 +248,36 @@ def time_series_plot(history, benchmark, run, height=250, width=1000):
         name="benchmark",
     )
 
+    p.legend.title_text_color = "darkgray"
+    p.legend.title = f"{len(history)} observations"
     p.legend.location = "bottom_left"
 
-    return p
+    range_tool = bokeh.models.RangeTool(x_range=p.x_range)
+    range_tool.overlay.fill_color = "gainsboro"
+    range_tool.overlay.fill_alpha = 0.2
+
+    select = bokeh.plotting.figure(
+        title="drag the middle and edges of the selection box to change the range above",
+        height=80,
+        width=width,
+        y_range=p.y_range,
+        x_axis_type="datetime",
+        y_axis_type=None,
+        tools="",
+        toolbar_location=None,
+    )
+
+    select.line("x", "y", source=source)
+    select.ygrid.grid_line_color = None
+    select.add_tools(range_tool)
+    select.toolbar.active_multi = range_tool
+    select.axis.visible = False
+    select.title.text_font_style = "italic"
+
+    spacer = bokeh.plotting.figure(
+        toolbar_location=None,
+        height=20,
+    )
+    spacer.outline_line_color = None
+
+    return bokeh.layouts.column(p, spacer, select, spacer)
