@@ -39,6 +39,9 @@ class BenchmarkMixin:
         context = self._get_context(benchmark)
         context.pop("links", None)
         benchmark["context"] = context
+        info = self._get_info(benchmark)
+        info.pop("links", None)
+        benchmark["info"] = info
 
         return benchmark
 
@@ -56,6 +59,13 @@ class BenchmarkMixin:
             return {}
         return response.json
 
+    def _get_info(self, benchmark):
+        response = self.api_get_url(benchmark["links"]["info"])
+        if response.status_code != 200:
+            self.flash("Error getting info.")
+            return {}
+        return response.json
+
 
 class RunMixin:
     def get_display_run(self, run_id):
