@@ -7,6 +7,7 @@ import flask as f
 from ..app import rule
 from ..app._endpoint import AppEndpoint
 from ..app._plots import TimeSeriesPlotMixin, simple_bar_plot
+from ..app._util import augment
 from ..app.benchmarks import BenchmarkMixin, RunMixin
 from ..config import Config
 
@@ -19,6 +20,7 @@ class Compare(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
         compare_batches_url = f.url_for("app.compare-batches", compare_ids=unknown)
         baseline, contender, plot, plot_history = None, None, None, None
         baseline_run, contender_run = None, None
+        outlier_names, outlier_urls = None, None
 
         if comparisons and self.type == "batch":
             ids = {c["baseline_run_id"] for c in comparisons if c["baseline_run_id"]}
@@ -47,6 +49,26 @@ class Compare(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
         if comparisons and self.type == "benchmark":
             plot_history = self.get_history_plot(contender, contender_run)
 
+        if comparisons and self.type != "benchmark":
+            comparisons_by_id = {c["contender_id"]: c for c in comparisons}
+            if self.type == "run":
+                benchmarks, response = self._get_benchmarks(run_id=contender_id)
+            if self.type == "batch":
+                benchmarks, response = self._get_benchmarks(batch_id=contender_id)
+            if response.status_code != 200:
+                self.flash("Error getting benchmarks.")
+                return self.redirect("app.index")
+            for benchmark in benchmarks:
+                augment(benchmark)
+            outliers, outlier_ids, outlier_names = self.get_outliers(benchmarks)
+            outlier_urls = [
+                comparisons_by_id[x]["compare_benchmarks_url"] for x in outlier_ids
+            ]
+            plot_history = [
+                self.get_history_plot(b, contender_run, i)
+                for i, b in enumerate(outliers)
+            ]
+
         return self.render_template(
             self.html,
             application=Config.APPLICATION_NAME,
@@ -66,8 +88,17 @@ class Compare(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
             contender_run=contender_run,
             compare_runs_url=compare_runs_url,
             compare_batches_url=compare_batches_url,
+            outlier_names=outlier_names,
+            outlier_urls=outlier_urls,
         )
 
+    def _get_benchmarks(self, run_id=None, batch_id=None):
+        if run_id:
+            response = self.api_get("api.benchmarks", run_id=run_id)
+        if batch_id:
+            response = self.api_get("api.benchmarks", batch_id=batch_id)
+        return response.json, response
+
     def _get_plot(self, baseline, contender):
         baseline_copy = copy.deepcopy(baseline)
         contender_copy = copy.deepcopy(contender)
