@@ -49,38 +49,23 @@ s.Index(
 )
 
 
-def get_commit_index(repository):
-    ordered = (
-        Session.query(Commit.id, Commit.sha, Commit.timestamp)
-        .filter(Commit.repository == repository)
+def get_commits_up(commit, limit):
+    # NOTE this query will fail if commit.timestamp is None
+    return (
+        Session.query(Commit.id, Commit.timestamp)
+        .filter(Commit.repository == commit.repository)
         .filter(Commit.timestamp.isnot(None))
+        .filter(Commit.timestamp <= commit.timestamp)
         .order_by(Commit.timestamp.desc())
-    ).cte("ordered_commits")
-    return Session.query(ordered, func.row_number().over().label("row_number"))
-
-
-def get_sha_row_number(repository, sha):
-    index = get_commit_index(repository).subquery().alias("commit_index")
-    return Session.query(index.c.row_number).filter(index.c.sha == sha)
-
-
-def get_commits_up(repository, sha, limit):
-    index = get_commit_index(repository).subquery().alias("commit_index")
-    n = Session.query(index.c.row_number).filter(index.c.sha == sha).scalar_subquery()
-    return Session.query(index).filter(index.c.row_number >= n).limit(limit)
+        .limit(limit)
+    )
 
 
 def get_distribution(summary, limit):
     from ..entities.summary import Summary
 
     commits_up = (
-        get_commits_up(
-            summary.run.commit.repository,
-            summary.run.commit.sha,
-            limit,
-        )
-        .subquery()
-        .alias("commits_up")
+        get_commits_up(summary.run.commit, limit).subquery().alias("commits_up")
     )
 
     return (
@@ -106,6 +91,7 @@ def get_distribution(summary, limit):
             Summary.case_id,
             Summary.context_id,
             Machine.name,
+            Machine.gpu_count,
             Machine.cpu_core_count,
             Machine.cpu_thread_count,
             Machine.memory_bytes,
@@ -125,6 +111,9 @@ def get_distribution(summary, limit):
 def update_distribution(summary, limit):
     from ..db import engine
 
+    if summary.run.commit.timestamp is None:
+        return
+
     distribution = get_distribution(summary, limit).first()
 
     if not distribution:
@@ -166,6 +155,7 @@ def get_closest_parent(run):
         .filter(
             Run.name.like("commit: %"),
             Machine.id.in_(machine_ids),
+            Commit.timestamp.isnot(None),
             Commit.timestamp < commit.timestamp,
             Commit.repository == commit.repository,
         )
