@@ -17,8 +17,9 @@ CONBENCH_REPO = "https://github.com/conbench/conbench"
 def _expected_entity(summary):
     return _api_benchmark_entity(
         summary.id,
+        summary.case_id,
+        summary.info_id,
         summary.context_id,
-        summary.case.id,
         summary.batch_id,
         summary.run_id,
         summary.case.name,
@@ -288,13 +289,14 @@ class TestBenchmarkPost(_asserts.PostEnforcer):
     url = "/api/benchmarks/"
     valid_payload = _fixtures.VALID_PAYLOAD
     required_fields = [
-        "run_id",
         "batch_id",
-        "timestamp",
+        "context",
+        "info",
         "machine_info",
+        "run_id",
         "stats",
         "tags",
-        "context",
+        "timestamp",
     ]
 
     def test_create_benchmark(self, client):
@@ -315,6 +317,7 @@ class TestBenchmarkPost(_asserts.PostEnforcer):
         summary_2 = Summary.one(id=response.json["id"])
         assert summary_1.id != summary_2.id
         assert summary_1.case_id == summary_2.case_id
+        assert summary_1.info_id == summary_2.info_id
         assert summary_1.context_id == summary_2.context_id
         assert summary_1.run.machine_id == summary_2.run.machine_id
         assert summary_1.run_id != summary_2.run_id
